clc
clear 
close all 
% Author Sukun Cheng
% This code compares apparent attenuation and ki to see how much contribution there is from the other source terms.
% Comparision is presented pair by pair, seperated by command pause in code. Press ENTER moving to the next one. 

% Data covers WE3,6 and 7. Each wave event(WE) has multiple results by pairing different buoys (tracked by buoypair ID).
% Data sources are from project Collaboratory: Arctic Sea State DRI shared folder https://drive.google.com/drive/u/1/folders/0B9sD43IvmKdxbXprMWxSSG9WQTQ?resourcekey=0-kFWTMwEr_OtN2O1L1JLdqg


% freq     % frequency array
% data.ki_AMSR2SMOS       % kr is solved by IC3 using ice products _AMSR2SMOS
% data.ki_AMSR2SMOS       % ki is derived from full model using ice products AMSR2 and SMOS
% buoypairID              % use this index to retrivel more details from 
                          %  shared alpha_dataset/attenuation_coefficient_WE3.mat
                          %  use it like buoypair(buoypairID)
% ki derived from full model using AMSR2 ice concentration and SMOS ice thickness 
% In any case, in the marginal ice zone, when ice concentration is low (< 50%), SMOS thickness might slightly underestimate mean thickness ).

WEn = 3;
for j = 1:length(WEn)
    m = WEn(j);
    clear data
    % load ki
    %load(['./ki_kr_results_from_alpha_dataset_collaborative/ki_kr_freq_WE' num2str(m) '_Chengetal2017.mat']);
    load(['./ki_kr_freq_WE' num2str(m) '_Chengetal2017.mat']);
    % load apparent attenuation 
    load(['./attenuation_coefficient_WE' num2str(m) '.mat']);
    %% plot ki, derived from full model
    figure(1);
    for i = 1:length(data)
        y = data{i}.ki_AMSR2SMOS;
        y(y<1.e-6) = nan;
        semilogy(freq,y,'.-k');            
        hold on
        
        id = data{i}.buoypairID
        semilogy(buoypair(id).f,buoypair(id).alpha,'.-r'); 
        xlabel('frequency f [Hz]')
        ylabel(' q and q_a [m^{-1}]')
        set(gca,'yscale','log')
        legend('q','q_a')
        axis([0.05 0.45 5.e-7 1.e-1])
        grid on    
        box on
        pause
        title(['WE' num2str(m) ', AMSR2 + SMOS'])
    end
end
